# kfp-job
No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: version not set
- Package version: 1.0.0
- Build package: io.swagger.codegen.languages.PythonClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on Github, you can install directly from Github

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import kfp_job 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import kfp_job
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import kfp_job
from kfp_job.rest import ApiException
from pprint import pprint

# Configure API key authorization: Bearer
configuration = kfp_job.Configuration()
configuration.api_key['authorization'] = 'YOUR_API_KEY'
# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['authorization'] = 'Bearer'

# create an instance of the API class
api_instance = kfp_job.JobServiceApi(kfp_job.ApiClient(configuration))
body = kfp_job.ApiJob() # ApiJob | 

try:
    api_response = api_instance.create_job(body)
    pprint(api_response)
except ApiException as e:
    print("Exception when calling JobServiceApi->create_job: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*JobServiceApi* | [**create_job**](docs/JobServiceApi.md#create_job) | **POST** /apis/v1beta1/jobs | 
*JobServiceApi* | [**delete_job**](docs/JobServiceApi.md#delete_job) | **DELETE** /apis/v1beta1/jobs/{id} | 
*JobServiceApi* | [**disable_job**](docs/JobServiceApi.md#disable_job) | **POST** /apis/v1beta1/jobs/{id}/disable | 
*JobServiceApi* | [**enable_job**](docs/JobServiceApi.md#enable_job) | **POST** /apis/v1beta1/jobs/{id}/enable | 
*JobServiceApi* | [**get_job**](docs/JobServiceApi.md#get_job) | **GET** /apis/v1beta1/jobs/{id} | 
*JobServiceApi* | [**list_jobs**](docs/JobServiceApi.md#list_jobs) | **GET** /apis/v1beta1/jobs | 


## Documentation For Models

 - [ApiCronSchedule](docs/ApiCronSchedule.md)
 - [ApiJob](docs/ApiJob.md)
 - [ApiListJobsResponse](docs/ApiListJobsResponse.md)
 - [ApiParameter](docs/ApiParameter.md)
 - [ApiPeriodicSchedule](docs/ApiPeriodicSchedule.md)
 - [ApiPipelineSpec](docs/ApiPipelineSpec.md)
 - [ApiRelationship](docs/ApiRelationship.md)
 - [ApiResourceKey](docs/ApiResourceKey.md)
 - [ApiResourceReference](docs/ApiResourceReference.md)
 - [ApiResourceType](docs/ApiResourceType.md)
 - [ApiStatus](docs/ApiStatus.md)
 - [ApiTrigger](docs/ApiTrigger.md)
 - [JobMode](docs/JobMode.md)
 - [ProtobufAny](docs/ProtobufAny.md)


## Documentation For Authorization


## Bearer

- **Type**: API key
- **API key parameter name**: authorization
- **Location**: HTTP header


## Author



